@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 
-#ifndef HGSYNCBASEDIALOG_H
-#define HGSYNCBASEDIALOG_H
+#ifndef HGSYNCDIALOGBASE_H
+#define HGSYNCDIALOGBASE_H
 
 #include "hgwrapper.h"
 
@@ -51,7 +51,7 @@ class HgSyncBaseDialog : public DialogBase
 public:
     enum DialogType {PushDialog, PullDialog};
 
-    HgSyncBaseDialog(DialogType dialogType, QWidget *parent = 0);
+    explicit HgSyncBaseDialog(DialogType dialogType, QWidget *parent = 0);
 
 signals:
     void changeListAvailable();
@@ -110,5 +110,5 @@ protected:
 
 };
 
-#endif // HGSYNCBASEDIALOG_H
+#endif // HGSYNCDIALOGBASE_H
 
